pub struct Webhooks { /* private fields */ }Implementations
Sourceimpl Webhooks
impl Webhooks
Sourcepub async fn create(&self, config: CreateWebhookConfig) -> Result<Webhook>
pub async fn create(&self, config: CreateWebhookConfig) -> Result<Webhook>
Sourcepub async fn update(
&self,
id: impl AsRef<str>,
config: UpdateWebhookConfig,
) -> Result<Webhook>
pub async fn update( &self, id: impl AsRef<str>, config: UpdateWebhookConfig, ) -> Result<Webhook>
Sourcepub async fn list(&self) -> Result<WebhookListResponse>
pub async fn list(&self) -> Result<WebhookListResponse>
Sourcepub async fn list_with_config(
&self,
config: ListWebhooksConfig,
) -> Result<WebhookListResponse>
pub async fn list_with_config( &self, config: ListWebhooksConfig, ) -> Result<WebhookListResponse>
Lists webhooks with pagination config.
Errors
Returns an error when the request fails or the config is invalid.
Sourcepub async fn delete_with_config(
&self,
id: impl AsRef<str>,
config: DeleteWebhookConfig,
) -> Result<WebhookDeleteResponse>
pub async fn delete_with_config( &self, id: impl AsRef<str>, config: DeleteWebhookConfig, ) -> Result<WebhookDeleteResponse>
Sourcepub async fn get_with_config(
&self,
id: impl AsRef<str>,
config: GetWebhookConfig,
) -> Result<Webhook>
pub async fn get_with_config( &self, id: impl AsRef<str>, config: GetWebhookConfig, ) -> Result<Webhook>
Sourcepub async fn ping_with_config(
&self,
id: impl AsRef<str>,
config: PingWebhookConfig,
) -> Result<WebhookPingResponse>
pub async fn ping_with_config( &self, id: impl AsRef<str>, config: PingWebhookConfig, ) -> Result<WebhookPingResponse>
Sourcepub async fn rotate_signing_secret(
&self,
id: impl AsRef<str>,
) -> Result<WebhookRotateSigningSecretResponse>
pub async fn rotate_signing_secret( &self, id: impl AsRef<str>, ) -> Result<WebhookRotateSigningSecretResponse>
Sourcepub async fn rotate_signing_secret_with_config(
&self,
id: impl AsRef<str>,
config: RotateWebhookSigningSecretConfig,
) -> Result<WebhookRotateSigningSecretResponse>
pub async fn rotate_signing_secret_with_config( &self, id: impl AsRef<str>, config: RotateWebhookSigningSecretConfig, ) -> Result<WebhookRotateSigningSecretResponse>
Rotates the signing secret for a webhook with config.
Errors
Returns an error when the request fails.